Play Free Now | Star Wars: The Old Republic
Description: Official site. BioWare and LucasArts bring you the next evolution in MMO Gameplay: Story.
Keywords: Star Wars, Star Wars Games, online game, mmo, mmorpg, rpg, information, BioWare, Bioware games, LucasArts, Lucasarts games, Star Wars The Old Republic, The Old Republic, Knights of the Old Republic MMO, KOTOR MMO, KOTOR, TOR, SWTOR, SWTOR MMO, Star Wars MMO, BioWare MMO, LucasArts MMO, massively multiplayer online game, massively multiplayer online role playing game

Play Now
En Fr De
Log In Sign Up

# Play Free Now

# Play Free* Now!

## Your Personal Star Wars™ Saga Starts Here!

Display Name
Password
Confirm Password
Country
What's your date of birth:
I have read & accept the EA Terms of Service and the EA Privacy Policy.
By creating an EA/Origin account for use with Star Wars™: The Old Republic™, I agree that my Star Wars: The Old Republic account information, game play details and data will be shared with LucasArts and used consistently with the LucasArts Privacy Policy.

Already have an account? Login or Download the Game

*SWTOR's Free-to-Play option contains some gameplay restrictions that limit access to certain features and content. For more information on these limitations please visit: www.StarWarsTheOldRepublic.com/FREE/features.

Terms Archive | Privacy Policy | Terms of Service | FAQ | EUALA | Rules of Conduct | Online Safety | Contact Us
LucasArts, the LucasArts logo, STAR WARS and related properties are trademarks in the United States and/or in other countries of Lucasfilm Ltd. and/or its affiliates. © 2013-2014 Lucasfilm Entertainment Company Ltd. or Lucasfilm Ltd. All rights reserved. BioWare and the BioWare logo are trademarks of EA International (Studio and Publishing) Ltd. EA and the EA logo are trademarks of Electronic Arts Inc. All other trademarks are the property of their respective owners.

## You are about to leave this website...

This page is not meant to keep you from following the link you've clicked on. It is just a warning that you are about to leave this website. To go to this page, click the link below.

If you do not wish to follow this link, simply close this message.

The statements and opinions expressed on these websites are solely those of their respective authors and do not necessarily reflect the views, nor are they endorsed by Bioware, LucasArts, and its licensors do not guarantee the accuracy of, and are in no way responsible for any content on these websites, and the Star Wars: The Old Republic privacy policy does not apply to their information collection practices.

Close Continue